#include <iostream>
#include <vector>

using namespace std;

const size_t SCREEN_WIDTH = 80;
const size_t MAX_ASTERISK = SCREEN_WIDTH - 3 - 1;

struct Input {
    vector<double> numbers;
    size_t bin_count{};
};

//  
Input input_data() {
    size_t number_count;
    cerr << "Enter number count: ";
    cin >> number_count;

    Input in;
    in.numbers.resize(number_count);

    cerr << "Enter numbers: ";
    for (size_t i = 0; i < number_count; i++) {
        cin >> in.numbers[i];
    }

    cerr << "Enter bin count: ";
    cin >> in.bin_count;

    return in;
}

//    
void find_minmax(const vector<double>& numbers, double& min, double& max) {
    min = numbers[0];
    max = numbers[0];

    for (double number : numbers) {
        if (number < min) {
            min = number;
        }
        if (number > max) {
            max = number;
        }
    }
}

//  
vector<size_t> make_histogram(const vector<double>& numbers, size_t bin_count) {
    vector<size_t> bins(bin_count, 0);

    double min, max;
    find_minmax(numbers, min, max);

    double bin_size = (max - min) / bin_count;

    for (double number : numbers) {
        bool found = false;
        for (size_t j = 0; (j < bin_count - 1) && !found; j++) {
            double lo = min + j * bin_size;
            double hi = min + (j + 1) * bin_size;
            if ((lo <= number) && (number < hi)) {
                bins[j]++;
                found = true;
            }
        }
        if (!found) {
            bins[bin_count - 1]++;
        }
    }

    return bins;
}

//  
void show_histogram_text(const vector<size_t>& bins) {
    size_t max_bin_count = 0;
    for (size_t bin : bins) {
        if (bin > max_bin_count) {
            max_bin_count = bin;
        }
    }

    if (max_bin_count <= MAX_ASTERISK) {
        for (size_t bin : bins) {
            if (bin < 10) cout << " ";
            cout << " " << bin << "|";
            for (size_t j = 0; j < bin; j++) {
                cout << "*";
            }
            cout << endl;
        }
    } else {
        for (size_t bin : bins) {
            size_t height = static_cast<size_t>(MAX_ASTERISK * (static_cast<double>(bin) / max_bin_count));
            if (bin < 100) cout << " ";
            if (bin < 10) cout << " ";
            cout << bin << "|";
            for (size_t j = 0; j < height; j++) {
                cout << "*";
            }
            cout << endl;
        }
    }
}

//  
int main() {
    Input in = input_data();
    vector<size_t> bins = make_histogram(in.numbers, in.bin_count);
    show_histogram_text(bins);
    return 0;
}
